Documentation
¶
Index ¶
- func Loop(ctx context.Context, interval time.Duration, f func(context.Context))
- func Poll(ctx context.Context, interval time.Duration, ...) error
- func PollValue[V any](ctx context.Context, interval time.Duration, ...) (V, error)
- func Until(ctx context.Context, interval time.Duration, f func(context.Context) error) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Poll ¶
Poll runs the given function at the start and again every interval until it either returns success (true and no error) or an error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.